sandboxtools

package
v0.0.0-...-5eaf458 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CopyFile

func CopyFile(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	sandboxID string,
	user string,
	sourcePath string,
	targetPath string,
) error

func RunCommand

func RunCommand(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	sandboxID string,
	command string,
	metadata metadata.Context,
) error

func RunCommandWithConfirmation

func RunCommandWithConfirmation(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	logger logger.Logger,
	lvl zapcore.Level,
	id string,
	sandboxID string,
	command string,
	metadata metadata.Context,
	confirmCh chan<- struct{},
) error

func RunCommandWithLogger

func RunCommandWithLogger(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	logger logger.Logger,
	lvl zapcore.Level,
	id string,
	sandboxID string,
	command string,
	metadata metadata.Context,
) error

func RunCommandWithOutput

func RunCommandWithOutput(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	sandboxID string,
	command string,
	metadata metadata.Context,
	processOutput func(stdout, stderr string),
) error

func SyncChangesToDisk

func SyncChangesToDisk(
	ctx context.Context,
	proxy *proxy.SandboxProxy,
	sandboxID string,
) error

syncChangesToDisk synchronizes filesystem changes to the filesystem This is useful to ensure that all changes made in the sandbox are written to disk to be able to re-create the sandbox without resume.

Types

This section is empty.

Jump to