proxygrpc

package
v0.0.0-...-f2c360d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

const (
	// MetadataTrafficAccessToken is forwarded by client-proxy when present.
	MetadataTrafficAccessToken = "e2b-traffic-access-token"
	// MetadataSandboxRequestPort identifies the original requested sandbox port.
	MetadataSandboxRequestPort = "e2b-sandbox-request-port"
	// MetadataEnvdAccessToken is forwarded by client-proxy for envd traffic on secure sandboxes.
	MetadataEnvdAccessToken = "e2b-envd-access-token"
	// MetadataAuthorization carries bearer credentials for gRPC requests.
	MetadataAuthorization = "authorization"
	// ScopeSandboxLifecycle authorizes client-proxy sandbox lifecycle operations.
	ScopeSandboxLifecycle = "sandboxes:lifecycle"
	// MetadataEnvdHTTPAccessToken is the HTTP header used by envd for access token authentication.
	MetadataEnvdHTTPAccessToken = "X-Access-Token"
)
const (
	SandboxService_ResumeSandbox_FullMethodName = "/proxy.SandboxService/ResumeSandbox"
)
const (
	// SandboxStillTransitioningMessage identifies the explicit transient autoresume wait failure.
	SandboxStillTransitioningMessage = "sandbox is still transitioning"
)

Variables

var File_proxy_proto protoreflect.FileDescriptor
var SandboxService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "proxy.SandboxService",
	HandlerType: (*SandboxServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ResumeSandbox",
			Handler:    _SandboxService_ResumeSandbox_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proxy.proto",
}

SandboxService_ServiceDesc is the grpc.ServiceDesc for SandboxService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterSandboxServiceServer

func RegisterSandboxServiceServer(s grpc.ServiceRegistrar, srv SandboxServiceServer)

Types

type SandboxResumeRequest

type SandboxResumeRequest struct {

	// Sandbox ID to resume.
	SandboxId string `protobuf:"bytes,1,opt,name=sandbox_id,json=sandboxId,proto3" json:"sandbox_id,omitempty"`
	// contains filtered or unexported fields
}

Request to resume a paused sandbox.

func (*SandboxResumeRequest) Descriptor deprecated

func (*SandboxResumeRequest) Descriptor() ([]byte, []int)

Deprecated: Use SandboxResumeRequest.ProtoReflect.Descriptor instead.

func (*SandboxResumeRequest) GetSandboxId

func (x *SandboxResumeRequest) GetSandboxId() string

func (*SandboxResumeRequest) ProtoMessage

func (*SandboxResumeRequest) ProtoMessage()

func (*SandboxResumeRequest) ProtoReflect

func (x *SandboxResumeRequest) ProtoReflect() protoreflect.Message

func (*SandboxResumeRequest) Reset

func (x *SandboxResumeRequest) Reset()

func (*SandboxResumeRequest) String

func (x *SandboxResumeRequest) String() string

type SandboxResumeResponse

type SandboxResumeResponse struct {

	// Orchestrator node IP that can receive traffic for this sandbox.
	OrchestratorIp string `protobuf:"bytes,1,opt,name=orchestrator_ip,json=orchestratorIp,proto3" json:"orchestrator_ip,omitempty"`
	// contains filtered or unexported fields
}

Response with routing info for the resumed/running sandbox.

func (*SandboxResumeResponse) Descriptor deprecated

func (*SandboxResumeResponse) Descriptor() ([]byte, []int)

Deprecated: Use SandboxResumeResponse.ProtoReflect.Descriptor instead.

func (*SandboxResumeResponse) GetOrchestratorIp

func (x *SandboxResumeResponse) GetOrchestratorIp() string

func (*SandboxResumeResponse) ProtoMessage

func (*SandboxResumeResponse) ProtoMessage()

func (*SandboxResumeResponse) ProtoReflect

func (x *SandboxResumeResponse) ProtoReflect() protoreflect.Message

func (*SandboxResumeResponse) Reset

func (x *SandboxResumeResponse) Reset()

func (*SandboxResumeResponse) String

func (x *SandboxResumeResponse) String() string

type SandboxServiceClient

type SandboxServiceClient interface {
	ResumeSandbox(ctx context.Context, in *SandboxResumeRequest, opts ...grpc.CallOption) (*SandboxResumeResponse, error)
}

SandboxServiceClient is the client API for SandboxService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

SandboxService is used by the client-proxy to resume sandboxes.

type SandboxServiceServer

type SandboxServiceServer interface {
	ResumeSandbox(context.Context, *SandboxResumeRequest) (*SandboxResumeResponse, error)
	// contains filtered or unexported methods
}

SandboxServiceServer is the server API for SandboxService service. All implementations must embed UnimplementedSandboxServiceServer for forward compatibility.

SandboxService is used by the client-proxy to resume sandboxes.

type UnimplementedSandboxServiceServer

type UnimplementedSandboxServiceServer struct{}

UnimplementedSandboxServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedSandboxServiceServer) ResumeSandbox

type UnsafeSandboxServiceServer

type UnsafeSandboxServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSandboxServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SandboxServiceServer will result in compilation errors.

Jump to