Documentation
¶
Index ¶
- func CopyFile(ctx context.Context, proxy *proxy.SandboxProxy, sandboxID string, user string, ...) error
- func RunCommand(ctx context.Context, proxy *proxy.SandboxProxy, sandboxID string, ...) error
- func RunCommandWithConfirmation(ctx context.Context, proxy *proxy.SandboxProxy, logger logger.Logger, ...) error
- func RunCommandWithLogger(ctx context.Context, proxy *proxy.SandboxProxy, logger logger.Logger, ...) error
- func RunCommandWithOutput(ctx context.Context, proxy *proxy.SandboxProxy, sandboxID string, ...) error
- func SyncChangesToDisk(ctx context.Context, proxy *proxy.SandboxProxy, sandboxID string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunCommand ¶
func RunCommandWithLogger ¶
func RunCommandWithOutput ¶
func SyncChangesToDisk ¶
syncChangesToDisk synchronizes filesystem changes to the filesystem This is useful to ensure that all changes made in the sandbox are written to disk to be able to re-create the sandbox without resume.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.