Documentation
¶
Index ¶
- Variables
- type CreateWatcherRequest
- func (*CreateWatcherRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateWatcherRequest) GetAllowNetworkMounts() bool
- func (x *CreateWatcherRequest) GetIncludeEntry() bool
- func (x *CreateWatcherRequest) GetPath() string
- func (x *CreateWatcherRequest) GetRecursive() bool
- func (*CreateWatcherRequest) ProtoMessage()
- func (x *CreateWatcherRequest) ProtoReflect() protoreflect.Message
- func (x *CreateWatcherRequest) Reset()
- func (x *CreateWatcherRequest) String() string
- type CreateWatcherResponse
- func (*CreateWatcherResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateWatcherResponse) GetWatcherId() string
- func (*CreateWatcherResponse) ProtoMessage()
- func (x *CreateWatcherResponse) ProtoReflect() protoreflect.Message
- func (x *CreateWatcherResponse) Reset()
- func (x *CreateWatcherResponse) String() string
- type EntryInfo
- func (*EntryInfo) Descriptor() ([]byte, []int)deprecated
- func (x *EntryInfo) GetGroup() string
- func (x *EntryInfo) GetMetadata() map[string]string
- func (x *EntryInfo) GetMode() uint32
- func (x *EntryInfo) GetModifiedTime() *timestamppb.Timestamp
- func (x *EntryInfo) GetName() string
- func (x *EntryInfo) GetOwner() string
- func (x *EntryInfo) GetPath() string
- func (x *EntryInfo) GetPermissions() string
- func (x *EntryInfo) GetSize() int64
- func (x *EntryInfo) GetSymlinkTarget() string
- func (x *EntryInfo) GetType() FileType
- func (*EntryInfo) ProtoMessage()
- func (x *EntryInfo) ProtoReflect() protoreflect.Message
- func (x *EntryInfo) Reset()
- func (x *EntryInfo) String() string
- type EventType
- type FileType
- type FilesystemEvent
- func (*FilesystemEvent) Descriptor() ([]byte, []int)deprecated
- func (x *FilesystemEvent) GetEntry() *EntryInfo
- func (x *FilesystemEvent) GetName() string
- func (x *FilesystemEvent) GetType() EventType
- func (*FilesystemEvent) ProtoMessage()
- func (x *FilesystemEvent) ProtoReflect() protoreflect.Message
- func (x *FilesystemEvent) Reset()
- func (x *FilesystemEvent) String() string
- type GetWatcherEventsRequest
- func (*GetWatcherEventsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetWatcherEventsRequest) GetWatcherId() string
- func (*GetWatcherEventsRequest) ProtoMessage()
- func (x *GetWatcherEventsRequest) ProtoReflect() protoreflect.Message
- func (x *GetWatcherEventsRequest) Reset()
- func (x *GetWatcherEventsRequest) String() string
- type GetWatcherEventsResponse
- func (*GetWatcherEventsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetWatcherEventsResponse) GetEvents() []*FilesystemEvent
- func (*GetWatcherEventsResponse) ProtoMessage()
- func (x *GetWatcherEventsResponse) ProtoReflect() protoreflect.Message
- func (x *GetWatcherEventsResponse) Reset()
- func (x *GetWatcherEventsResponse) String() string
- type ListDirRequest
- func (*ListDirRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListDirRequest) GetDepth() uint32
- func (x *ListDirRequest) GetPath() string
- func (*ListDirRequest) ProtoMessage()
- func (x *ListDirRequest) ProtoReflect() protoreflect.Message
- func (x *ListDirRequest) Reset()
- func (x *ListDirRequest) String() string
- type ListDirResponse
- type MakeDirRequest
- type MakeDirResponse
- type MoveRequest
- func (*MoveRequest) Descriptor() ([]byte, []int)deprecated
- func (x *MoveRequest) GetDestination() string
- func (x *MoveRequest) GetSource() string
- func (*MoveRequest) ProtoMessage()
- func (x *MoveRequest) ProtoReflect() protoreflect.Message
- func (x *MoveRequest) Reset()
- func (x *MoveRequest) String() string
- type MoveResponse
- type RemoveRequest
- type RemoveResponse
- type RemoveWatcherRequest
- func (*RemoveWatcherRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RemoveWatcherRequest) GetWatcherId() string
- func (*RemoveWatcherRequest) ProtoMessage()
- func (x *RemoveWatcherRequest) ProtoReflect() protoreflect.Message
- func (x *RemoveWatcherRequest) Reset()
- func (x *RemoveWatcherRequest) String() string
- type RemoveWatcherResponse
- type StatRequest
- type StatResponse
- type WatchDirRequest
- func (*WatchDirRequest) Descriptor() ([]byte, []int)deprecated
- func (x *WatchDirRequest) GetAllowNetworkMounts() bool
- func (x *WatchDirRequest) GetIncludeEntry() bool
- func (x *WatchDirRequest) GetPath() string
- func (x *WatchDirRequest) GetRecursive() bool
- func (*WatchDirRequest) ProtoMessage()
- func (x *WatchDirRequest) ProtoReflect() protoreflect.Message
- func (x *WatchDirRequest) Reset()
- func (x *WatchDirRequest) String() string
- type WatchDirResponse
- func (*WatchDirResponse) Descriptor() ([]byte, []int)deprecated
- func (m *WatchDirResponse) GetEvent() isWatchDirResponse_Event
- func (x *WatchDirResponse) GetFilesystem() *FilesystemEvent
- func (x *WatchDirResponse) GetKeepalive() *WatchDirResponse_KeepAlive
- func (x *WatchDirResponse) GetStart() *WatchDirResponse_StartEvent
- func (*WatchDirResponse) ProtoMessage()
- func (x *WatchDirResponse) ProtoReflect() protoreflect.Message
- func (x *WatchDirResponse) Reset()
- func (x *WatchDirResponse) String() string
- type WatchDirResponse_Filesystem
- type WatchDirResponse_KeepAlive
- type WatchDirResponse_Keepalive
- type WatchDirResponse_Start
- type WatchDirResponse_StartEvent
Constants ¶
This section is empty.
Variables ¶
var ( FileType_name = map[int32]string{ 0: "FILE_TYPE_UNSPECIFIED", 1: "FILE_TYPE_FILE", 2: "FILE_TYPE_DIRECTORY", 3: "FILE_TYPE_SYMLINK", } FileType_value = map[string]int32{ "FILE_TYPE_UNSPECIFIED": 0, "FILE_TYPE_FILE": 1, "FILE_TYPE_DIRECTORY": 2, "FILE_TYPE_SYMLINK": 3, } )
Enum value maps for FileType.
var ( EventType_name = map[int32]string{ 0: "EVENT_TYPE_UNSPECIFIED", 1: "EVENT_TYPE_CREATE", 2: "EVENT_TYPE_WRITE", 3: "EVENT_TYPE_REMOVE", 4: "EVENT_TYPE_RENAME", 5: "EVENT_TYPE_CHMOD", } EventType_value = map[string]int32{ "EVENT_TYPE_UNSPECIFIED": 0, "EVENT_TYPE_CREATE": 1, "EVENT_TYPE_WRITE": 2, "EVENT_TYPE_REMOVE": 3, "EVENT_TYPE_RENAME": 4, "EVENT_TYPE_CHMOD": 5, } )
Enum value maps for EventType.
var File_filesystem_filesystem_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CreateWatcherRequest ¶
type CreateWatcherRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
Recursive bool `protobuf:"varint,2,opt,name=recursive,proto3" json:"recursive,omitempty"`
// If true, each FilesystemEvent includes the EntryInfo of the affected entry, when available.
IncludeEntry bool `protobuf:"varint,3,opt,name=include_entry,json=includeEntry,proto3" json:"include_entry,omitempty"`
// If true, allows watching paths on network filesystem mounts (NFS, CIFS, SMB, FUSE).
// Events on network mounts may be unreliable or not delivered at all.
AllowNetworkMounts bool `protobuf:"varint,4,opt,name=allow_network_mounts,json=allowNetworkMounts,proto3" json:"allow_network_mounts,omitempty"`
// contains filtered or unexported fields
}
func (*CreateWatcherRequest) Descriptor
deprecated
func (*CreateWatcherRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateWatcherRequest.ProtoReflect.Descriptor instead.
func (*CreateWatcherRequest) GetAllowNetworkMounts ¶
func (x *CreateWatcherRequest) GetAllowNetworkMounts() bool
func (*CreateWatcherRequest) GetIncludeEntry ¶
func (x *CreateWatcherRequest) GetIncludeEntry() bool
func (*CreateWatcherRequest) GetPath ¶
func (x *CreateWatcherRequest) GetPath() string
func (*CreateWatcherRequest) GetRecursive ¶
func (x *CreateWatcherRequest) GetRecursive() bool
func (*CreateWatcherRequest) ProtoMessage ¶
func (*CreateWatcherRequest) ProtoMessage()
func (*CreateWatcherRequest) ProtoReflect ¶
func (x *CreateWatcherRequest) ProtoReflect() protoreflect.Message
func (*CreateWatcherRequest) Reset ¶
func (x *CreateWatcherRequest) Reset()
func (*CreateWatcherRequest) String ¶
func (x *CreateWatcherRequest) String() string
type CreateWatcherResponse ¶
type CreateWatcherResponse struct {
WatcherId string `protobuf:"bytes,1,opt,name=watcher_id,json=watcherId,proto3" json:"watcher_id,omitempty"`
// contains filtered or unexported fields
}
func (*CreateWatcherResponse) Descriptor
deprecated
func (*CreateWatcherResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateWatcherResponse.ProtoReflect.Descriptor instead.
func (*CreateWatcherResponse) GetWatcherId ¶
func (x *CreateWatcherResponse) GetWatcherId() string
func (*CreateWatcherResponse) ProtoMessage ¶
func (*CreateWatcherResponse) ProtoMessage()
func (*CreateWatcherResponse) ProtoReflect ¶
func (x *CreateWatcherResponse) ProtoReflect() protoreflect.Message
func (*CreateWatcherResponse) Reset ¶
func (x *CreateWatcherResponse) Reset()
func (*CreateWatcherResponse) String ¶
func (x *CreateWatcherResponse) String() string
type EntryInfo ¶
type EntryInfo struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type FileType `protobuf:"varint,2,opt,name=type,proto3,enum=filesystem.FileType" json:"type,omitempty"`
Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
Size int64 `protobuf:"varint,4,opt,name=size,proto3" json:"size,omitempty"`
Mode uint32 `protobuf:"varint,5,opt,name=mode,proto3" json:"mode,omitempty"`
Permissions string `protobuf:"bytes,6,opt,name=permissions,proto3" json:"permissions,omitempty"`
Owner string `protobuf:"bytes,7,opt,name=owner,proto3" json:"owner,omitempty"`
Group string `protobuf:"bytes,8,opt,name=group,proto3" json:"group,omitempty"`
ModifiedTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=modified_time,json=modifiedTime,proto3" json:"modified_time,omitempty"`
// If the entry is a symlink, this field contains the target of the symlink.
SymlinkTarget *string `protobuf:"bytes,10,opt,name=symlink_target,json=symlinkTarget,proto3,oneof" json:"symlink_target,omitempty"`
// User-defined metadata stored as extended attributes (xattrs) on the file.
// Keys live under the `user.e2b.` xattr namespace; the prefix is stripped here.
// Plain `user.*` xattrs written by other tooling are not reflected.
Metadata map[string]string `` /* 158-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*EntryInfo) Descriptor
deprecated
func (*EntryInfo) GetMetadata ¶
func (*EntryInfo) GetModifiedTime ¶
func (x *EntryInfo) GetModifiedTime() *timestamppb.Timestamp
func (*EntryInfo) GetPermissions ¶
func (*EntryInfo) GetSymlinkTarget ¶
func (*EntryInfo) ProtoMessage ¶
func (*EntryInfo) ProtoMessage()
func (*EntryInfo) ProtoReflect ¶
func (x *EntryInfo) ProtoReflect() protoreflect.Message
type EventType ¶
type EventType int32
func (EventType) Descriptor ¶
func (EventType) Descriptor() protoreflect.EnumDescriptor
func (EventType) EnumDescriptor
deprecated
func (EventType) Number ¶
func (x EventType) Number() protoreflect.EnumNumber
func (EventType) Type ¶
func (EventType) Type() protoreflect.EnumType
type FileType ¶
type FileType int32
func (FileType) Descriptor ¶
func (FileType) Descriptor() protoreflect.EnumDescriptor
func (FileType) EnumDescriptor
deprecated
func (FileType) Number ¶
func (x FileType) Number() protoreflect.EnumNumber
func (FileType) Type ¶
func (FileType) Type() protoreflect.EnumType
type FilesystemEvent ¶
type FilesystemEvent struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type EventType `protobuf:"varint,2,opt,name=type,proto3,enum=filesystem.EventType" json:"type,omitempty"`
// Info of the entry that triggered the event. Only populated when include_entry
// was requested and the entry could be stat-ed (e.g. not set for remove/rename-away
// events, where the entry no longer exists at this path).
Entry *EntryInfo `protobuf:"bytes,3,opt,name=entry,proto3,oneof" json:"entry,omitempty"`
// contains filtered or unexported fields
}
func (*FilesystemEvent) Descriptor
deprecated
func (*FilesystemEvent) Descriptor() ([]byte, []int)
Deprecated: Use FilesystemEvent.ProtoReflect.Descriptor instead.
func (*FilesystemEvent) GetEntry ¶
func (x *FilesystemEvent) GetEntry() *EntryInfo
func (*FilesystemEvent) GetName ¶
func (x *FilesystemEvent) GetName() string
func (*FilesystemEvent) GetType ¶
func (x *FilesystemEvent) GetType() EventType
func (*FilesystemEvent) ProtoMessage ¶
func (*FilesystemEvent) ProtoMessage()
func (*FilesystemEvent) ProtoReflect ¶
func (x *FilesystemEvent) ProtoReflect() protoreflect.Message
func (*FilesystemEvent) Reset ¶
func (x *FilesystemEvent) Reset()
func (*FilesystemEvent) String ¶
func (x *FilesystemEvent) String() string
type GetWatcherEventsRequest ¶
type GetWatcherEventsRequest struct {
WatcherId string `protobuf:"bytes,1,opt,name=watcher_id,json=watcherId,proto3" json:"watcher_id,omitempty"`
// contains filtered or unexported fields
}
func (*GetWatcherEventsRequest) Descriptor
deprecated
func (*GetWatcherEventsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetWatcherEventsRequest.ProtoReflect.Descriptor instead.
func (*GetWatcherEventsRequest) GetWatcherId ¶
func (x *GetWatcherEventsRequest) GetWatcherId() string
func (*GetWatcherEventsRequest) ProtoMessage ¶
func (*GetWatcherEventsRequest) ProtoMessage()
func (*GetWatcherEventsRequest) ProtoReflect ¶
func (x *GetWatcherEventsRequest) ProtoReflect() protoreflect.Message
func (*GetWatcherEventsRequest) Reset ¶
func (x *GetWatcherEventsRequest) Reset()
func (*GetWatcherEventsRequest) String ¶
func (x *GetWatcherEventsRequest) String() string
type GetWatcherEventsResponse ¶
type GetWatcherEventsResponse struct {
Events []*FilesystemEvent `protobuf:"bytes,1,rep,name=events,proto3" json:"events,omitempty"`
// contains filtered or unexported fields
}
func (*GetWatcherEventsResponse) Descriptor
deprecated
func (*GetWatcherEventsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetWatcherEventsResponse.ProtoReflect.Descriptor instead.
func (*GetWatcherEventsResponse) GetEvents ¶
func (x *GetWatcherEventsResponse) GetEvents() []*FilesystemEvent
func (*GetWatcherEventsResponse) ProtoMessage ¶
func (*GetWatcherEventsResponse) ProtoMessage()
func (*GetWatcherEventsResponse) ProtoReflect ¶
func (x *GetWatcherEventsResponse) ProtoReflect() protoreflect.Message
func (*GetWatcherEventsResponse) Reset ¶
func (x *GetWatcherEventsResponse) Reset()
func (*GetWatcherEventsResponse) String ¶
func (x *GetWatcherEventsResponse) String() string
type ListDirRequest ¶
type ListDirRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
Depth uint32 `protobuf:"varint,2,opt,name=depth,proto3" json:"depth,omitempty"`
// contains filtered or unexported fields
}
func (*ListDirRequest) Descriptor
deprecated
func (*ListDirRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListDirRequest.ProtoReflect.Descriptor instead.
func (*ListDirRequest) GetDepth ¶
func (x *ListDirRequest) GetDepth() uint32
func (*ListDirRequest) GetPath ¶
func (x *ListDirRequest) GetPath() string
func (*ListDirRequest) ProtoMessage ¶
func (*ListDirRequest) ProtoMessage()
func (*ListDirRequest) ProtoReflect ¶
func (x *ListDirRequest) ProtoReflect() protoreflect.Message
func (*ListDirRequest) Reset ¶
func (x *ListDirRequest) Reset()
func (*ListDirRequest) String ¶
func (x *ListDirRequest) String() string
type ListDirResponse ¶
type ListDirResponse struct {
Entries []*EntryInfo `protobuf:"bytes,1,rep,name=entries,proto3" json:"entries,omitempty"`
// contains filtered or unexported fields
}
func (*ListDirResponse) Descriptor
deprecated
func (*ListDirResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListDirResponse.ProtoReflect.Descriptor instead.
func (*ListDirResponse) GetEntries ¶
func (x *ListDirResponse) GetEntries() []*EntryInfo
func (*ListDirResponse) ProtoMessage ¶
func (*ListDirResponse) ProtoMessage()
func (*ListDirResponse) ProtoReflect ¶
func (x *ListDirResponse) ProtoReflect() protoreflect.Message
func (*ListDirResponse) Reset ¶
func (x *ListDirResponse) Reset()
func (*ListDirResponse) String ¶
func (x *ListDirResponse) String() string
type MakeDirRequest ¶
type MakeDirRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*MakeDirRequest) Descriptor
deprecated
func (*MakeDirRequest) Descriptor() ([]byte, []int)
Deprecated: Use MakeDirRequest.ProtoReflect.Descriptor instead.
func (*MakeDirRequest) GetPath ¶
func (x *MakeDirRequest) GetPath() string
func (*MakeDirRequest) ProtoMessage ¶
func (*MakeDirRequest) ProtoMessage()
func (*MakeDirRequest) ProtoReflect ¶
func (x *MakeDirRequest) ProtoReflect() protoreflect.Message
func (*MakeDirRequest) Reset ¶
func (x *MakeDirRequest) Reset()
func (*MakeDirRequest) String ¶
func (x *MakeDirRequest) String() string
type MakeDirResponse ¶
type MakeDirResponse struct {
Entry *EntryInfo `protobuf:"bytes,1,opt,name=entry,proto3" json:"entry,omitempty"`
// contains filtered or unexported fields
}
func (*MakeDirResponse) Descriptor
deprecated
func (*MakeDirResponse) Descriptor() ([]byte, []int)
Deprecated: Use MakeDirResponse.ProtoReflect.Descriptor instead.
func (*MakeDirResponse) GetEntry ¶
func (x *MakeDirResponse) GetEntry() *EntryInfo
func (*MakeDirResponse) ProtoMessage ¶
func (*MakeDirResponse) ProtoMessage()
func (*MakeDirResponse) ProtoReflect ¶
func (x *MakeDirResponse) ProtoReflect() protoreflect.Message
func (*MakeDirResponse) Reset ¶
func (x *MakeDirResponse) Reset()
func (*MakeDirResponse) String ¶
func (x *MakeDirResponse) String() string
type MoveRequest ¶
type MoveRequest struct {
Source string `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
Destination string `protobuf:"bytes,2,opt,name=destination,proto3" json:"destination,omitempty"`
// contains filtered or unexported fields
}
func (*MoveRequest) Descriptor
deprecated
func (*MoveRequest) Descriptor() ([]byte, []int)
Deprecated: Use MoveRequest.ProtoReflect.Descriptor instead.
func (*MoveRequest) GetDestination ¶
func (x *MoveRequest) GetDestination() string
func (*MoveRequest) GetSource ¶
func (x *MoveRequest) GetSource() string
func (*MoveRequest) ProtoMessage ¶
func (*MoveRequest) ProtoMessage()
func (*MoveRequest) ProtoReflect ¶
func (x *MoveRequest) ProtoReflect() protoreflect.Message
func (*MoveRequest) Reset ¶
func (x *MoveRequest) Reset()
func (*MoveRequest) String ¶
func (x *MoveRequest) String() string
type MoveResponse ¶
type MoveResponse struct {
Entry *EntryInfo `protobuf:"bytes,1,opt,name=entry,proto3" json:"entry,omitempty"`
// contains filtered or unexported fields
}
func (*MoveResponse) Descriptor
deprecated
func (*MoveResponse) Descriptor() ([]byte, []int)
Deprecated: Use MoveResponse.ProtoReflect.Descriptor instead.
func (*MoveResponse) GetEntry ¶
func (x *MoveResponse) GetEntry() *EntryInfo
func (*MoveResponse) ProtoMessage ¶
func (*MoveResponse) ProtoMessage()
func (*MoveResponse) ProtoReflect ¶
func (x *MoveResponse) ProtoReflect() protoreflect.Message
func (*MoveResponse) Reset ¶
func (x *MoveResponse) Reset()
func (*MoveResponse) String ¶
func (x *MoveResponse) String() string
type RemoveRequest ¶
type RemoveRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*RemoveRequest) Descriptor
deprecated
func (*RemoveRequest) Descriptor() ([]byte, []int)
Deprecated: Use RemoveRequest.ProtoReflect.Descriptor instead.
func (*RemoveRequest) GetPath ¶
func (x *RemoveRequest) GetPath() string
func (*RemoveRequest) ProtoMessage ¶
func (*RemoveRequest) ProtoMessage()
func (*RemoveRequest) ProtoReflect ¶
func (x *RemoveRequest) ProtoReflect() protoreflect.Message
func (*RemoveRequest) Reset ¶
func (x *RemoveRequest) Reset()
func (*RemoveRequest) String ¶
func (x *RemoveRequest) String() string
type RemoveResponse ¶
type RemoveResponse struct {
// contains filtered or unexported fields
}
func (*RemoveResponse) Descriptor
deprecated
func (*RemoveResponse) Descriptor() ([]byte, []int)
Deprecated: Use RemoveResponse.ProtoReflect.Descriptor instead.
func (*RemoveResponse) ProtoMessage ¶
func (*RemoveResponse) ProtoMessage()
func (*RemoveResponse) ProtoReflect ¶
func (x *RemoveResponse) ProtoReflect() protoreflect.Message
func (*RemoveResponse) Reset ¶
func (x *RemoveResponse) Reset()
func (*RemoveResponse) String ¶
func (x *RemoveResponse) String() string
type RemoveWatcherRequest ¶
type RemoveWatcherRequest struct {
WatcherId string `protobuf:"bytes,1,opt,name=watcher_id,json=watcherId,proto3" json:"watcher_id,omitempty"`
// contains filtered or unexported fields
}
func (*RemoveWatcherRequest) Descriptor
deprecated
func (*RemoveWatcherRequest) Descriptor() ([]byte, []int)
Deprecated: Use RemoveWatcherRequest.ProtoReflect.Descriptor instead.
func (*RemoveWatcherRequest) GetWatcherId ¶
func (x *RemoveWatcherRequest) GetWatcherId() string
func (*RemoveWatcherRequest) ProtoMessage ¶
func (*RemoveWatcherRequest) ProtoMessage()
func (*RemoveWatcherRequest) ProtoReflect ¶
func (x *RemoveWatcherRequest) ProtoReflect() protoreflect.Message
func (*RemoveWatcherRequest) Reset ¶
func (x *RemoveWatcherRequest) Reset()
func (*RemoveWatcherRequest) String ¶
func (x *RemoveWatcherRequest) String() string
type RemoveWatcherResponse ¶
type RemoveWatcherResponse struct {
// contains filtered or unexported fields
}
func (*RemoveWatcherResponse) Descriptor
deprecated
func (*RemoveWatcherResponse) Descriptor() ([]byte, []int)
Deprecated: Use RemoveWatcherResponse.ProtoReflect.Descriptor instead.
func (*RemoveWatcherResponse) ProtoMessage ¶
func (*RemoveWatcherResponse) ProtoMessage()
func (*RemoveWatcherResponse) ProtoReflect ¶
func (x *RemoveWatcherResponse) ProtoReflect() protoreflect.Message
func (*RemoveWatcherResponse) Reset ¶
func (x *RemoveWatcherResponse) Reset()
func (*RemoveWatcherResponse) String ¶
func (x *RemoveWatcherResponse) String() string
type StatRequest ¶
type StatRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*StatRequest) Descriptor
deprecated
func (*StatRequest) Descriptor() ([]byte, []int)
Deprecated: Use StatRequest.ProtoReflect.Descriptor instead.
func (*StatRequest) GetPath ¶
func (x *StatRequest) GetPath() string
func (*StatRequest) ProtoMessage ¶
func (*StatRequest) ProtoMessage()
func (*StatRequest) ProtoReflect ¶
func (x *StatRequest) ProtoReflect() protoreflect.Message
func (*StatRequest) Reset ¶
func (x *StatRequest) Reset()
func (*StatRequest) String ¶
func (x *StatRequest) String() string
type StatResponse ¶
type StatResponse struct {
Entry *EntryInfo `protobuf:"bytes,1,opt,name=entry,proto3" json:"entry,omitempty"`
// contains filtered or unexported fields
}
func (*StatResponse) Descriptor
deprecated
func (*StatResponse) Descriptor() ([]byte, []int)
Deprecated: Use StatResponse.ProtoReflect.Descriptor instead.
func (*StatResponse) GetEntry ¶
func (x *StatResponse) GetEntry() *EntryInfo
func (*StatResponse) ProtoMessage ¶
func (*StatResponse) ProtoMessage()
func (*StatResponse) ProtoReflect ¶
func (x *StatResponse) ProtoReflect() protoreflect.Message
func (*StatResponse) Reset ¶
func (x *StatResponse) Reset()
func (*StatResponse) String ¶
func (x *StatResponse) String() string
type WatchDirRequest ¶
type WatchDirRequest struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
Recursive bool `protobuf:"varint,2,opt,name=recursive,proto3" json:"recursive,omitempty"`
// If true, each FilesystemEvent includes the EntryInfo of the affected entry, when available.
IncludeEntry bool `protobuf:"varint,3,opt,name=include_entry,json=includeEntry,proto3" json:"include_entry,omitempty"`
// If true, allows watching paths on network filesystem mounts (NFS, CIFS, SMB, FUSE).
// Events on network mounts may be unreliable or not delivered at all.
AllowNetworkMounts bool `protobuf:"varint,4,opt,name=allow_network_mounts,json=allowNetworkMounts,proto3" json:"allow_network_mounts,omitempty"`
// contains filtered or unexported fields
}
func (*WatchDirRequest) Descriptor
deprecated
func (*WatchDirRequest) Descriptor() ([]byte, []int)
Deprecated: Use WatchDirRequest.ProtoReflect.Descriptor instead.
func (*WatchDirRequest) GetAllowNetworkMounts ¶
func (x *WatchDirRequest) GetAllowNetworkMounts() bool
func (*WatchDirRequest) GetIncludeEntry ¶
func (x *WatchDirRequest) GetIncludeEntry() bool
func (*WatchDirRequest) GetPath ¶
func (x *WatchDirRequest) GetPath() string
func (*WatchDirRequest) GetRecursive ¶
func (x *WatchDirRequest) GetRecursive() bool
func (*WatchDirRequest) ProtoMessage ¶
func (*WatchDirRequest) ProtoMessage()
func (*WatchDirRequest) ProtoReflect ¶
func (x *WatchDirRequest) ProtoReflect() protoreflect.Message
func (*WatchDirRequest) Reset ¶
func (x *WatchDirRequest) Reset()
func (*WatchDirRequest) String ¶
func (x *WatchDirRequest) String() string
type WatchDirResponse ¶
type WatchDirResponse struct {
// Types that are assignable to Event:
// *WatchDirResponse_Start
// *WatchDirResponse_Filesystem
// *WatchDirResponse_Keepalive
Event isWatchDirResponse_Event `protobuf_oneof:"event"`
// contains filtered or unexported fields
}
func (*WatchDirResponse) Descriptor
deprecated
func (*WatchDirResponse) Descriptor() ([]byte, []int)
Deprecated: Use WatchDirResponse.ProtoReflect.Descriptor instead.
func (*WatchDirResponse) GetEvent ¶
func (m *WatchDirResponse) GetEvent() isWatchDirResponse_Event
func (*WatchDirResponse) GetFilesystem ¶
func (x *WatchDirResponse) GetFilesystem() *FilesystemEvent
func (*WatchDirResponse) GetKeepalive ¶
func (x *WatchDirResponse) GetKeepalive() *WatchDirResponse_KeepAlive
func (*WatchDirResponse) GetStart ¶
func (x *WatchDirResponse) GetStart() *WatchDirResponse_StartEvent
func (*WatchDirResponse) ProtoMessage ¶
func (*WatchDirResponse) ProtoMessage()
func (*WatchDirResponse) ProtoReflect ¶
func (x *WatchDirResponse) ProtoReflect() protoreflect.Message
func (*WatchDirResponse) Reset ¶
func (x *WatchDirResponse) Reset()
func (*WatchDirResponse) String ¶
func (x *WatchDirResponse) String() string
type WatchDirResponse_Filesystem ¶
type WatchDirResponse_Filesystem struct {
Filesystem *FilesystemEvent `protobuf:"bytes,2,opt,name=filesystem,proto3,oneof"`
}
type WatchDirResponse_KeepAlive ¶
type WatchDirResponse_KeepAlive struct {
// contains filtered or unexported fields
}
func (*WatchDirResponse_KeepAlive) Descriptor
deprecated
func (*WatchDirResponse_KeepAlive) Descriptor() ([]byte, []int)
Deprecated: Use WatchDirResponse_KeepAlive.ProtoReflect.Descriptor instead.
func (*WatchDirResponse_KeepAlive) ProtoMessage ¶
func (*WatchDirResponse_KeepAlive) ProtoMessage()
func (*WatchDirResponse_KeepAlive) ProtoReflect ¶
func (x *WatchDirResponse_KeepAlive) ProtoReflect() protoreflect.Message
func (*WatchDirResponse_KeepAlive) Reset ¶
func (x *WatchDirResponse_KeepAlive) Reset()
func (*WatchDirResponse_KeepAlive) String ¶
func (x *WatchDirResponse_KeepAlive) String() string
type WatchDirResponse_Keepalive ¶
type WatchDirResponse_Keepalive struct {
Keepalive *WatchDirResponse_KeepAlive `protobuf:"bytes,3,opt,name=keepalive,proto3,oneof"`
}
type WatchDirResponse_Start ¶
type WatchDirResponse_Start struct {
Start *WatchDirResponse_StartEvent `protobuf:"bytes,1,opt,name=start,proto3,oneof"`
}
type WatchDirResponse_StartEvent ¶
type WatchDirResponse_StartEvent struct {
// contains filtered or unexported fields
}
func (*WatchDirResponse_StartEvent) Descriptor
deprecated
func (*WatchDirResponse_StartEvent) Descriptor() ([]byte, []int)
Deprecated: Use WatchDirResponse_StartEvent.ProtoReflect.Descriptor instead.
func (*WatchDirResponse_StartEvent) ProtoMessage ¶
func (*WatchDirResponse_StartEvent) ProtoMessage()
func (*WatchDirResponse_StartEvent) ProtoReflect ¶
func (x *WatchDirResponse_StartEvent) ProtoReflect() protoreflect.Message
func (*WatchDirResponse_StartEvent) Reset ¶
func (x *WatchDirResponse_StartEvent) Reset()
func (*WatchDirResponse_StartEvent) String ¶
func (x *WatchDirResponse_StartEvent) String() string