Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store[SourceItem any, PoolItem any] interface { SourceList(ctx context.Context) ([]SourceItem, error) SourceExists(ctx context.Context, s []SourceItem, p PoolItem) bool PoolList(ctx context.Context) []PoolItem PoolExists(ctx context.Context, s SourceItem) bool PoolInsert(ctx context.Context, s SourceItem) PoolUpdate(ctx context.Context, s PoolItem) PoolRemove(ctx context.Context, s PoolItem) }
type Synchronize ¶
Synchronize is a generic type that provides methods for synchronizing a pool of items with a source. It uses a Store interface to interact with the source and pool, allowing for flexible synchronization logic.
func NewSynchronize ¶
func (*Synchronize[SourceItem, PoolItem]) Close ¶
func (s *Synchronize[SourceItem, PoolItem]) Close()
Click to show internal directories.
Click to hide internal directories.